This is a port of [BabelStream](https://github.com/UoB-HPC/BabelStream) to alpaka.
This work is based on the [cupla port of BabelStream]( https://github.com/jyoung3131/BabelStream) from Jeff Young.
The benchmark driver (main.cpp and Stream.h) is taken from BabelStream.
No other backends are available, only alpaka.
Thus, there is no need to select a backend, just run the executable.
Please refer to the BabelStream documentation of more information on how to run the benchmark.
